import {AdRecord} from "../records/ad.record";
import {pool} from "../utils/db";
import {AdEntity} from "../types";

const defaultObj = {
    name: 'Test Name',
    description: 'blah',
    url: 'https://example.com',
    price: 0,
    lat: 9,
    lon: 9,
}

//Po wykonaniu wszystkich testów zakańczamy połączenie z bazą danych
afterAll(async () => {
    await pool.end();

});

test('AdRecord.getOne returns data from database for one entry.', async () => {

    const ad = await AdRecord.getOne('abc');

    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('Testowa');

});

test('AdRecord.getOne returns null from database for unexisting entry.', async () => {

    const ad = await AdRecord.getOne('---');

    expect(ad).toBeNull();

});

test('AdRecords.findAll returns array of found entries.', async ()  => {

    const ads = await AdRecord.findAll('');

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();


});

test('AdRecords.findAll returns array of found entries when searching for "a".', async ()  => {

    const ads = await AdRecord.findAll('a');

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();


});

test('AdRecords.findAll returns empty array when searching for something that does not exists.', async ()  => {

    const ads = await AdRecord.findAll('----------------------');

    expect(ads).toEqual([]);

});


//Testujemy czy funkcja zwraca tylko bezpieczne dane tzn te okrojone o opis cenę i url.
test('AdRecords.findAll returns smaller amount of data.', async ()  => {

    const ads = await AdRecord.findAll('');

    expect((ads[0] as AdEntity).price).toBeUndefined();
    expect((ads[0] as AdEntity).description).toBeUndefined();
    expect((ads[0] as AdEntity).url).toBeUndefined();

});

//Testujemy czy funkcja zwraca tylko bezpieczne dane tzn te okrojone o opis cenę i url.
test('AdRecords.insert returns new UUID.', async () => {

    const ad = new AdRecord(defaultObj)

    await ad.insert();

    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');

});

//Testujemy czy funkcja zwraca tylko bezpieczne dane tzn te okrojone o opis cenę i url.
test('AdRecords.insert inserts data to database.', async () => {

    const ad = new AdRecord(defaultObj)

    await ad.insert();

    const foundAd = await AdRecord.getOne(ad.id);

    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);

});