"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FlashcardRecord = void 0;
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class FlashcardRecord {
    constructor(obj) {
        this.id = obj.id;
        this.front = obj.front;
        this.back = obj.back;
        this.category = obj.category;
        this.status = obj.status;
    }
    // static async getOneForUser(userId: string, flashcardId: string): Promise<FlashcardRecord | null> {
    //     const [result] = await pool.execute("SELECT * FROM `flashcards` WHERE `status`=':status' AND `id`=:id OR `status` = 'public' AND `id`=:id;", {
    //         status: userId,
    //         id: flashcardId,
    //     }) as FlashcardRecordResults;
    //     console.log(result[0]);
    //     return result.length === 0 ? null : new FlashcardRecord(result[0]);
    // }
    static findAllForUser(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute("SELECT * FROM `flashcards` WHERE `status`=:status OR `status` = 'public' ORDER BY `front` ASC;", {
                status: userId,
            });
            return result;
        });
    }
    static findOneForUserByFront(userId, front) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute("SELECT * FROM `flashcards` WHERE `front` = :front AND `status`= :status OR `status` = 'public' AND `front` = :front;", {
                status: userId,
                front: front,
            });
            return result.length === 0 ? null : result;
        });
    }
    static findOneRandomForUser(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute("SELECT * FROM `flashcards` WHERE `status`=:status OR `status` = 'public' ORDER BY RAND() LIMIT 1;", {
                status: userId,
            });
            return result;
        });
    }
    static addFlashcard(front, back, category, status) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("INSERT INTO `flashcards` VALUES (:id, :front, :back, :category, :status);", {
                id: (0, uuid_1.v4)(),
                front: front,
                back: back,
                category: category,
                status: status,
            });
        });
    }
    static removeFlashcard(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('DELETE FROM `flashcards` WHERE `id` = :id;', {
                id: id,
            });
        });
    }
}
exports.FlashcardRecord = FlashcardRecord;
//# sourceMappingURL=flashcard.record.js.map